<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu_ES">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Honi buruz </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Honi buruz</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Bertsioa</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Egilea</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Diruz lagundu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontaktua</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Lizentzia: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Pantaila argazkia eta oharrak hartzeko tresna</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Lasterbidea</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Garbitu</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Argazkia egin</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Kurtsorea hartu</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Atzerapena</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Argazki modua</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Erakutsi irudia finkatutako leihoan</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Kopiatu irudia arbelera</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Kargatu irudia</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Ireki irudien direktorio nagusia</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Gorde irudia</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Ezkutatu leiho nagusia</translation>
    </message>
    <message>
        <source>Global</source>
        <translation>Orokorra</translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation>Gaituta dagoenean lasterbidea egingo du
eskuragarri ksnip-ek fokurik ez duenean ere.</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Gehitu</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Ekintzen ezarpenak</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ekintza</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Ur-markarako irudia behar da</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Ur-markarako irudia gehitu honela Aukerak &gt; Ezarpenak &gt; Ohar-hartzailea &gt; Eguneratu</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Leundu marrazkien lineak</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Aktibatuta dagoenean, leundu arkatza eta
markatzailearen lerroak marrazketa bukatzean.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Leuntze faktorea</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Leuntze faktorean handitzeak arkatza
eta markatzailearen zehaztasun galera dakar,
haien leuntasuna areagotuz.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Nabarmentzearen ezarpenak</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Gogoratu ohargilearen hautaketa eta kargatu abiatzean</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Aldatu Hautatu tresnara elementua marraztu ondoren</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Zenbakien tresna aldatzean zenbaki elementu guztiak eguneratzen dira</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Aukera hau desgaitzeak zenbakien tresnan aldaketak eragiten ditu
soilik elementu berrietan, baina ez dauden elementuak.
Aukera hau desgaitzeak zenbaki bikoiztuak edukitzea ahalbidetzen du.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Oihalaren kolorea</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Oharpen-eremurako oihalaren atzeko planoaren kolore lehenetsia.
Koloreak aldatzeak oharpen gune berriei eragiten die.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Hautatu elementua marraztu ondoren</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Aukera hau gaituta dagoenean, elementua hautatuta geratzen 
da sortu ondoren, hartara ezarpenak aldatu daitezke.</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation>Erakutsi kontrolen widgeta</translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation>Kontrolen widgetak du: Desegin/Berregin,
Moztu, Eskalatu, Biratu eta Aldatu Canvas botoiak.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Kapturatu pantaila-argazkia abiaraztean modu lehenetsian</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Aplikazioaren estiloa</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Erabiltzailearen Interfaze Grafikoaren itxura ezartzen du.
Ksnip berrabiarazi behar du aldaketek eragina izateko.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Aplikazioaren ezarpenak</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Kopiatu kaptura berriak arbelera automatikoki</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Erabili fitxak</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Aldaketak berrabiaraztea eskatzen du.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Erabili ksnip instantzia bakarrean</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ezkutatu fitxen barra fitxa bakarra dagoenean.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Aukera hau gaituz gero ksnip instantzia bakarra exekutatu ahal izango da,
haren ondoren abiatutako beste instantziek lehenegoari pasatuko diote euren
argumentuak eta itxiko dira. Aukera hau aldatzeak instantzia guztiak berrabiaraztea
eskatzen du.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Gogoratu leiho nagusiaren kokapena mugitzean eta kargatu abioan</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Ezkutatu fitxak automatikoki</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Auto ezkutatu kaiak</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Ezkutatu tresna barra eta oharpen ezarpenak abiatzean.
Kaien ikusgarritasuna Tab teklarekin txandakatu daiteke.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Aldatu automatikoki tamainara egokituz</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Aldatu automatikoki leiho nagusiaren tamaina edukiaren irudira doitzeko.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Gaitu arazketa</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Arazte-irteera gaitzen du kontsolan idatzita.
Ksnip berrabiarazi behar da eragina izateko.</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Edukira doitzeko atzerapena Leiho-kudeatzaileari eduki berria jaso ahal izateko
atzerapena da. Leiho nagusia eduki berrira behar bezala doitzen ez bada,
atzerapen hori handitzeak portaera hobe dezake.</translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation>Aldatu atzerapena</translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation>Temp direktorioa</translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation>Temp direktorioa aldi baterako irudiak gordetzeko erabiltzen da,
ksnip itxi ondoren ezabatu egingo da.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Arakatu</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Laguntzaileak:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Gaztelerako itzulpena</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Alemanerako itzulpena</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Errusierako itzulpena</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Norvegierako itzulpena</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Frantseserako itzulpena</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Polonierako itzulpena</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap eta Flatpak euskarria</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Egileak:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Oharra - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>%1%2%3 argazkia aldatu da.
Nahi duzu gordetzea?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Berria</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Marraztu area laukizuzena saguaren bidez</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Egin pantailan hautatutako azken area laukizuzenaren argazkia</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Egin monitore guztiak barne hartzen dituen pantaila-argazkia</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Egin sagua kokatuta dagoen pantailaren argazkia</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Egin fokuratuta dagoen leihoaren argazkia</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Egin kurtsorearen azpian dagoenaren argazkia</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Pantaila-argazkien ataria erabiltzen du pantaila-argazkia egiteko</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Komunitatea</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Erroreen txostenak</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Galdera orokorrak edo ideiak badituzu edo ksnip-i buruz hitz egin nahi baduzu,&lt;br/&gt;sartu gure %1 edo %2 zerbitzarian.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Erabili %1 akatsen berri emateko.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Arbelera kopiatzeak huts egin du</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Arbelera base54 kodetutako irudi gisa kopiatzeak huts egin du.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Arbelera kopiatu da</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Arbelera base64 kodetutako irudi gisa kopiatu da.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Ezabatu irudia</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>&apos;%1&apos; elementua ezabatuko da.
Jarraitu nahi duzu?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Diru-laguntzak beti dira ongi etorriak</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Dohaintza</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip irabazi asmorik gabeko copyleft libreko software proiektu bat da, eta&lt;br/&gt;oraindik estali beharreko kostu batzuk ditu,&lt;br/&gt;esaterako, domeinu-kostuak edo hardware-kostuak plataforma anitzeko zerbitzua emateko.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Garatzaileei garagardo bat edo kafe bat gonbidatuz lagundu nahi baduzu edo besterik gabe eskertu nahi baduzu egiten ari den lana&lt;br/&gt;, %1 hemen%2 egin dezakezu.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Githuben babeslea izan nahi duzu?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Hori ere posible da, %1hemen%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Gehitu ekintza berriak &apos;Gehitu&apos; fitxaren botoia sakatuta.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Area laukizuzena</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Azken area laukizuzena</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Pantaila osoa (monitore guztiak)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Uneko pantaila</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Leiho aktiboa</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Kurtsorearen azpiko leihoa</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Pantaila argazkien ataria</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Behartu karga anonimoa.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Erabiltzaile-izena</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Pasahitza</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP kargatzailea</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Karga ongi burutu da</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Ezin izan da irudia behin behinean gorde kargatzeko.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Ezin izan da prozesua abiarazi, begiratu bidea eta baimenak.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Prozesuak huts egin du</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Prozesuaren epemuga agortu da.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Prozesuaren irakurketa errorea.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Prozesuaren irakurketa errorea.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Web errorea, begiratu kontsolaren irteera.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Kargak huts egin du</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>StdErr-ra bidalitako scripta.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP karga behar bezala burutu da.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Errore ezezaguna</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Konexio errorea.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Baimen errorea.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>% 1 script-aren karga behar bezala amaitu da.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>%1-era kargatu da</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Aktibatuta laster-tekla globalak</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Egin laukizuzenaren arearen argazkia</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Egin azken laukizuzenaren arearen argazkia</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Egin pantaila osoaren argazkia</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Egin uneko pantailaren argazkia</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Egin leiho aktiboaren argazkia</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Egin kurtsore azpiko leihoaren argazkia</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Laster-teklak</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Garbitu</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Egin argazkia atariaren bidez</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Laster-teklak une honetan bakarrik onartzen dira Windows eta X11n.
Aukera hau desgaituz gero, ekintza lasterbideak ksnip-en soilik izango dira.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Kurtsorea sartu pantailaren argazkian</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Kurtsorea pantailen argazkietan
ikusiko da.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Irudien kapturatzailea</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>XDG-DESKTOP-PORTAL erabiltzen duten Wayland
inplementazio generikoak pantailaren eskalatzea
desberdin egiten du. Aukera hau gaituz gero
zehaztu uneko pantailaren eskala eta aplikatu
hori ksnip-eko pantailan.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOMEk eta KDE Plasma-k onartzen ditu beren Wayland 
eta XDG-DESKTOP-PORTAL generikoaren pantaila-argazkiak.
Aukera hau gaitzeak behartzen ditu KDE Plasma eta
GNOME pantaila-argazkiak XDG-DESKTOP-PORTALaren bidez egiten.
Aukera hau aldatzeak ksnip berrabiaraztea eskatzen du.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Erakutsi leiho nagusia pantaila-argazkia egin ondoren</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ezkutatu leiho nagusia pantaila-argazkiak egitean</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ezkutatu leiho nagusia pantaila-argazki berria egitean.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Erakutsi leiho nagusia pantaila argazki berri bat egin ondoren
leiho nagusia ezkutuan edo minimizatuta dagoenean.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Behartu Generic Wayland (xdg-desktop-portal) pantaila-argazkia</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Eskalatu Generic Wayland (xdg-desktop-portal) pantaila-argazkia</translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation>Kapturaren atzerapen inplizitua</translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation>Atzerapen hau atzerapenik hautatu ez denean erabiltzen 
da, Ksnip pantaila-argazki bat egin aurretik ezkutatzeko 
aukera ematen du. Balio hau ez da aplikatzen Ksnip 
dagoeneko minimizatuta badago. Balio hori murrizteak 
eragin dezake Ksnip-en leiho nagusia pantaila-argazkian 
agertzea.</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur historia</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Denbora-zigilua</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Esteka</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Ezabatu esteka</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>imgur.com gunera kargatu da!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Token berri bat jaso da, berriro kargatzen saiatzen…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur-en tokena iraungi da, token berria eskatzen…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Behartu karga anonimoa</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Kargatu ondoren ireki Imgur-en esteka lehenetsitako nabigatzailean</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Estekatu irudia zuzenean</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Kopiatu beti Imgur-en esteka arbelera</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Bezeroaren ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Bezeroaren sekretua</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PINa</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Sartu imgur-en Pina haren truke tokena eskuratzeko.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Eskuratu PINa</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Eskuratu tokena</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur historia</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-en kargatzailea</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Erabiltzaile-izena</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>imgur.com-en zain…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com-en tokena behar bezala eguneratu da.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com-en tokenaren eguneraketak huts egin du.</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Url oinarria:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Imgur-ekin komunikatzeko erabiliko den url oinarria.
Aldatzeak berrabiaraztea eskatzen du.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Garbitu Tokena</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation>Kargatu izenburua:</translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation>Kargatu deskribapena:</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Ezin izan da irudia ireki</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Ezin izan da irudia path %1-tik ireki</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Berria</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Atzerapena segundotan aktibazioa
eta pantaila-argazkiaren artean.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gorde</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Gorde pantaila-argazkia fitxategi-sisteman</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiatu</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Kopiatu pantaila-argazkia arbelera</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desegin</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Berregin</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Moztu</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Moztu pantaila-argazkia</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Tresnak</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation>Ezin da irudia erakutsi</translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation>Gorde gabe</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Kargatu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Inprimatu</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Irekitzen du inprimagailuaren elkarrizketa-koadroa eta irudia inprimatzeko aukera ematen du</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Inprimatzeko aurrebista</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Irekitzen du inprimatzeko aurrebistaren elkarrizketa-koadroa non irudiaren orientazioa alda daitekeen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Eskalatu</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Gehitu ur-marka</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Gehitu ur-marka egindako argazkiari. Hainbat ur-marka gehitu daitezke.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Irten</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ezarpenak</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Honi buruz</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ireki</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxategia</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editatu</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Laguntza</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Gorde honela...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Itsatsi</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Itsatsi kapsulatua</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Ainguratu</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Finkatu pantaila-argazkia markorik gabeko lehen plano batean</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Espero bazen arren, ez da irudirik jaso.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiatu bidea</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ireki direktorioa</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ikusi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ezabatu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Aldatu izena</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Ireki irudiak</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Erakutsi kaiak</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Ezkutatu kaiak</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>URl data gisa kopiatu da</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Ireki duela gutxikoa</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Aldatu oihala</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Kargatu egindako argazkia kanpoko iturri batera</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Kopiatu egindako argazkia sistemaren arbelera</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Eskalako irudia</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Biratu</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Biratu irudia</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ekintzak</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Irudi fitxategiak</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Gorde guztiak</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Itxi leihoa</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Moztu</translation>
    </message>
    <message>
        <source>OCR</source>
        <translation>OCR</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Gorde</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Gorde honela</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ireki direktorioa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiatu</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiatu bidea</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ezabatu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Aldatu izena</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Gorde guztiak</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Argazkia</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation>OCR leihoa %1</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Itxi besteak</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Itxi denak</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation>OCR leihoa %1</translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation>Bilaketa-bidea</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Lehenetsia</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation>Pluginak dauden direktorioa.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Arakatu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Bertsioa</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation>Antzeman</translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation>Plugin ezarpenak</translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation>Plugin kokapena</translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation>Prozesatzen</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Irudia berrizendatua</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Irudiaren berrizendatzeak huts egin du</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Berrizendatu irudia</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Fitxategi-izen berria:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Irudiari %1 izen berria ezarri zaio</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Ezin izan da %1 izena ezarri irudiari</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Gorde honela</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Fitxategi guztiak</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Irudia gorde da</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Irudiaren gordetzeak huts egin du</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Irudi fitxategiak</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1 izenarekin gorde da</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Ezin izan da %1 izenarekin gorde</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Gorde automatikoki kaptura berriak lehenetsitako kokagunera</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Eskatu gordetzea gorde gabeko aldaketak baztertu aurretik</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Gogoratu gordetzeko erabilitako azken direktorioa</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Aktibatuta dagoenean ezarpenetan gordetako direktorioa gainidatziko du
gordetzeko erabilitako karpetarekin, gordetzen den aldiro.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Atzitu gordetzeko kokapena eta fitxategiaren izena</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Onartzen diren formatuak dira JPG, PNG eta BMP. Formaturik zehazten ez bada, PNG erabiliko da lehenetsi gisa.
Fitxategiaren izenak honako komodinak eduki ditzake:
- $Y, $M, $D datarako, $h, $m, $s ordurako, edo $T denborarako hhmmss formatuan.
- Hainbat # jarraian kontagailurako. #### bihurtuko da 0001 eta hurrengo argazkian 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Arakatu</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Gordetze-ezarpenak</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Gordetzeko kokapena</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Lehenetsia</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Faktorea</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Gordetze kalitatea</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Jarri 0 konprimitutako fitxategi txikiak sortzeko, 100 konpresiorik gabeko fitxategiak sortzeko.
Irudi formatu guztiek ez dute gama osoa onartzen, JPEG-ek bai.</translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation>Gainidatzi fitxategia izen berdinarekin</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopiatu irteerako scripta arbelera</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Scripta:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Kargan eskatuko den scriptaren bidea. Kargan scripta erabiliko da behin behineko
png fitxategi baten bidea argumentu sinplea duela.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Arakatu</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Kargarako scripta</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Hautatu kargarako scripta</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Gelditu kargako scripta StdErr-ra gehitzean</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Scriptak StdErr-ra gehitzeak huts egin duela markatzen du.
Ezarpen hau gabe scripteko akatsak oharkabean geratuko dira.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Iragazkia:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>RegEx adierazpena. Kopiatu arbelera bakarrik RegEx adierazpenarekin bat datorrenarekin.
Ez badago, dena kopiatzen da.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ezarpenak</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikazioa</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Irudi kapturatzailea</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-en kargatzailea</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Ohargilea</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Laster-teklak</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Kargagailua</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Kargako scripta</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Gordetzea</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Eranskailuak</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Argazki-area</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Erretiluko ikonoa</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Ur-marka</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ekintzak</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP kargatzailea</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pluginak</translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation>Bilaketa ezarpenak...</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Hautatutako zuzenaren tamaina aldatu heldulekuak erabiliz edo mugitu hautapena arrastatuz.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Erabili gezi-teklak hautaketa mugitzeko.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Erabili gezi-teklak CTRL sakatzen duzun bitartean goiko ezkerreko heldulekua mugitzeko.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Erabili gezi-teklak ALT sakatzen duzun bitartean beheko eskuineko heldulekua mugitzeko.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Mezu hau ezarpenen bidez desgaitu daiteke.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation>Berretsi hautapena SARTU sakatuz edo saguaren klik bikoitza egin edozein lekutan.</translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation>Utzi ESC sakatuz.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Egin klik eta arrastatu area laukizuzena hautatzeko edo ESC ateratzeko.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Mantendu CTRL sakatuta hautaketaren tamaina aldatzeko.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Mantendu CTRL sakatuta hautatu ondoren tamaina aldatzea ekiditeko.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Eragiketa bertan behera geratuko da 60 segundoren buruan hautaketa egin ez denean.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Mezu hau ezarpenen bidez desgaitu daiteke.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Izoztu irudia markatu bitartean</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Aktibatuta dagoenean atzeko planoa izoztuko da
area laukizuzena hautatu bitartean. Atzeratutako
pantailen portaera ere aldatzen du, aukera hau
aktibatuta atzerapena argazki-area erakutsi aurretik 
gertatzen da eta aukera desgaituta dagonean
atzerapena argazki-area erakutsi ondoren gertatzen da.
Ezaugarri hau beti desgaituta dago Wayland-entzat eta beti
aktibatuta MacOs-entzat.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Erakutsi lupa argazki-arean</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Erakutsi atzeko planoko irudia handitzen duen
lupa. Aukera honek bakarrik funtzionatzen du
&quot;Izoztu irudia markatu bitartean&quot; aktibatuta badago.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Erakutsi argazki-arearen erregelak</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Lerro horizontal eta bertikalak zabaltzen dira
mahaigainaren izkinetatik kurtsorera argazki-zonan.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Erakutsi argaki-arearen kokapena eta tamainaren informazioa</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Saguaren ezkerreko botoia sakatu gabe kokapena
ikusten da, sakatuta dagoenean, hautatutako 
arearen tamaina ikusten da haren goiko ezker
aldean.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Onartu berez hautatutako area laukizuzenaren tamaina aldatzea</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Gaituta badago onartzen da hautatutako 
arearen tamaina aldatzea. Tamaina aldatu
ondoren hautaketa berretsi behar da Sartu
sakatuta.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Erakutsi argazki-arearen informazioa</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Argazki-arearen kurtsorearen kolorea</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Argazki-arearen kurtsorearen kolorea ezartzen du.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Argazki-arearen kurtsorearen zabalera</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Argazki-arearen kurtsorearen lodiera ezartzen du.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Argazki-area</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Argazki-arearen dekorazioaren kolorea</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Argazki-arearen dekorazio elementuen
kolorea ezartzen du.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Argazki-arearen gardentasuna</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Argazki-areako hautatu gabeko zonaren Alpha.
Zenbaki txikiagoak gardenagoa adierazten du.</translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation>Gaitu ebakitzeko eremuaren desplazamendua</translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation>Gaituta dagoenean konfiguratutako 
desplazamendua aplikatuko zaio mozteko 
areari posiziora kokapena behar bezala 
kalkulatuta ez denean. Hau batzuetan 
beharrezkoa da pantaila eskalatzea 
gaituta dagoenean.</translation>
    </message>
    <message>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Gora</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Behera</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Erabili berezko eranskailuak</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Eranskailuen ezarpenak</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Irudi bektorialen fitxategiak (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Gehitu</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kendu</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Gehitu eranskailuak</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Erakutsi editorea</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Erabili erretiluko ikonoa</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Aktibatuta dagoenean, sistemaren erretiluan ikonoa gehituko du, sistemaren leiho kudeatzaileak onartzen badu.
Aldaketak berrabiaraztea eskatzen du.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimizatu erretilura</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Abiatu erretiluan minimizatua</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Itxi erretilura</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Erakutsi editorea</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Argazkia</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Erretiluko ikonoaren eragiketa lehenetsia</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Erretiluaren ikonoan ezkerreko klik egitean aktibatzen den eragiketa lehenetsia.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Erretiluko ikonoaren ezarpenak</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Erabili plataformaren berariazko jakinarazpen zerbitzua</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Aktibatuta dagoenean saiatuko da plataformaren berariazko jakinarazpen
zerbitzua erabiltzen baldin badago. Aldaketak berrabiaraztea eskatzen du eragina izateko.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Bistaratu erretiluko ikonoaren jakinarazpenak</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Aukeratu irudia</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Irudi fitxategiak</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Kargarako scripta behar da</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Gehitu kargarako script bat Aukerak » Ezarpenak » Kargarako scripta</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Argazkiaren karga</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Argazkia kanpoko kokapen batera igotzear zaude, ekin nahi diozu?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Eskatu berrespena kargatu aurretik</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Karga mota:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Scripta</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Kargagailua</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Bertsioa</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Sorrera</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Erabiltzen:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Ur-markaren irudia</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Eguneratu</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Biratu ur-marka</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Aktibatuta dagoenean, ur-marka 45ªko biraketarekin gehituko da</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Ur-markaren ezarpenak</translation>
    </message>
</context>
</TS>
